function [T, Y]=mechanical_system
 
f=0;    % Free Vibration %
tspan=[0,10];    % t0=0, tf=1 sec %
y0=[1;0];       % s0=0, v0=0 %
options = odeset('RelTol',1e-4,'AbsTol',[1e-4 1e-4]);
 
%% (1) Under Damped
% mass-damper-spring constants %
m=1; b=0; k=1; 
% State-space Equation %
A=[0,1;-k/m,-b/m]; b=[0; 1/m]; u=f;
[T1,Y1] = ode45(@(t,y) equation_of_motion(t, y, A, b, u),tspan,y0,options);
 
%% (2) Critically Damped
% mass-damper-spring constants %
m=1; b=2; k=1; 
% State-space Equation %
A=[0,1;-k/m,-b/m]; b=[0; 1/m]; u=f;
[T2,Y2] = ode45(@(t,y) equation_of_motion(t, y, A, b, u),tspan,y0,options);
 
%% (3) Over Damped
% mass-damper-spring constants %
m=1; b=10; k=1; 
% State-space Equation %
A=[0,1;-k/m,-b/m]; b=[0; 1/m]; u=f;
[T3,Y3] = ode45(@(t,y) equation_of_motion(t, y, A, b, u),tspan,y0,options);
 
figure(1)
subplot(1,3,1), plot(T1,Y1(:,1));
title('Under damped system');
xlabel('time [sec]'); ylabel('displacement [m]'); grid on;
subplot(1,3,2), plot(T2,Y2(:,1));
title('Critically damped system');
xlabel('time [sec]'); ylabel('displacement [m]'); grid on;
subplot(1,3,3), plot(T3,Y3(:,1));
title('Over damped system');
xlabel('time [sec]'); ylabel('displacement [m]'); grid on;
 
function dy=equation_of_motion(t, y, A, b, u)
dy=A*y+b*u;
