%% Main Fuction %%
function []=eightbar()
clc;

% Constants %
D2R=pi/180; R2D=180/pi;

n=1;
for th2=0*D2R: 5*D2R: 360*D2R
    
    [pmat]=Left_Mechanism(th2);

    % Draw a 3-DOF Planar Robot %
    %------- Figure Settings
    clf;
    figure(1);
    axis([-150, 150, -150, 150]);
    xlabel('x-axis'); ylabel('y-axis');
    grid on;
    draw_mechanism(pmat);
    
    fpoint(:,n)=pmat(:,8);
    xdata(n)=th2/D2R;
    ydata(:,n)=pmat(:,8);
        
    n=n+1;
    pause(0.1);
%{    
    disp('C34:'); disp(c34');
    disp('C78:'); disp(c78');
    disp('C56:'); disp(c56');
    disp('C910:'); disp(c910');
    disp('C1112:'); disp(c1112');
%}
end

% Draw the trace of the foot point %
draw_fpoint(fpoint);

% Results %
figure(2);
plot(xdata, ydata(1,:),'k-', xdata, ydata(2,:),'k:');
xlabel('theta2 [deg]');
ylabel('X & Y Positions [mm]');
grid on;

function [pmat]=Left_Mechanism(th2)

% Link Lengths %
%Z1=90; Z2=28; Z3=128; Z4=83; Z5=128; Z6=83; Z7=115; Z8=83; Z9=83; Z10=83; Z11=166; Z12=144;
%r=52.5/90;
%(r/7.5)*[90,28,128,83,128,83,115,83,83,83,166,144]

p=7.5; Z1=7*p; Z2=2*p; Z3=9*p; Z5=9*p; 
Z4=6*p; Z7=9*p; Z8=6*p; Z10=6*p;
Z6=6*p; Z9=6*p; Z11=11*p; Z12=9*p;

% Step0: Inputs %
c12=[0,0]';
c14=Z1*[-1,0]';
c23=Z2*[cos(th2),sin(th2)]';

% Step1: Find C34 from C23 & C14 %
[c34]=inter_point(c14,Z4,c23,Z3,+1);
% Step2: Find C78 from C14 & C34 %
[c78]=inter_point(c14,Z8,c34,Z7,+1);
% Step3: Find C56 from C14 & C23 %
[c56]=inter_point(c14,Z6,c23,Z5,-1);
% Step4: Find C910 from C78 & C56 %
[c910]=inter_point(c78,Z9,c56,Z10,-1);
% Step10: Find C1112 from C56 & C910 %
[c1112]=inter_point(c56,Z12,c910,Z11,+1);
pmat=[c12,c23,c34,c14,c56,c78,c910,c1112];

% Find the intersection points of two circles %
function [pout]=inter_point(c1,r1,c2,r2, index)

th=atan2(c2(2,1)-c1(2,1),c2(1,1)-c1(1,1));
d=norm(c2-c1);
if d>1.e-8
    px1=(d^2+r1^2-r2^2)/(2*d);
    py1=index*sqrt(r1^2-px1^2);
else
    px1=0;
    py1=0;
end
pout=[cos(th)*px1-sin(th)*py1+c1(1,1);...
    sin(th)*px1+cos(th)*py1+c1(2,1)];
 

%% Draw Primitives %%
%-------- Draw a Mechanism
function draw_mechanism(pm)
%pmat=[c12,c23,c34,c14,c56,c78,c910,c1112];

sc_f=50; draw_frame(eye(4,4), sc_f);         % Fixed Frame %

lw=2; clr=[0,0,1];
% Draw the Z1 %
draw_line(pm(:,1),pm(:,4),lw,clr);
% Draw the Z2 %
draw_line(pm(:,1),pm(:,2),lw,clr);
% Draw the Z3 %
draw_line(pm(:,2),pm(:,3),lw,clr);

clr=[0,1,0.5];
% Draw the Z4 %
draw_line(pm(:,3),pm(:,4),lw,clr);
% Draw the Z7 %
draw_line(pm(:,3),pm(:,6),lw,clr);
% Draw the Z8 %
draw_line(pm(:,4),pm(:,6),lw,clr);

clr=[0,1,1];
% Draw the Z5 %
draw_line(pm(:,2),pm(:,5),lw,clr);
% Draw the Z6 %
draw_line(pm(:,4),pm(:,5),lw,clr);
% Draw the Z9 %
draw_line(pm(:,6),pm(:,7),lw,clr);

clr=[0,0,1];
% Draw the Z10 %
draw_line(pm(:,5),pm(:,7),lw,clr);
% Draw the Z11 %
draw_line(pm(:,7),pm(:,8),lw,clr);
% Draw the Z12 %
draw_line(pm(:,5),pm(:,8),lw,clr);

function draw_fpoint(fpoint)

[m,n]=size(fpoint);

lw=1; clr=[0,0,0];
for i=1:n-1
    draw_line(fpoint(:,i), fpoint(:,i+1),lw,clr);
end
draw_line(fpoint(:,n), fpoint(:,1),lw,clr);
    

%-------- Draw a Frame
function draw_frame(T, sc)
p1=T*[0,0,0,1]'; p2=T*[sc,0,0,1]'; lw=2; clr=[1,0,0];
draw_line(p1(1:2,1),p2(1:2,1),lw,clr);
p1=T*[0,0,0,1]'; p2=T*[0,sc,0,1]'; lw=2; clr=[0,1,0];
draw_line(p1(1:2,1),p2(1:2,1),lw,clr);
p1=T*[0,0,0,1]'; p2=T*[0,0,sc,1]'; lw=2; clr=[0,0,1];
draw_line(p1(1:2,1),p2(1:2,1),lw,clr);
 
%------- Draw a Line
function draw_line(p1, p2, lw, clr)
line([p1(1,1),p2(1,1)],[p1(2,1),p2(2,1)],'LineWidth',lw,'Color',clr);

